# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Field.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='Field.proto',
  package='iobinary',
  syntax='proto2',
  serialized_options=b'\n\024de.dlr.fame.protobufB\005Field',
  serialized_pb=b'\n\x0b\x46ield.proto\x12\x08iobinary\"\xc0\x01\n\x0bNestedField\x12\x11\n\tfieldName\x18\x01 \x02(\t\x12\x1d\n\x08seriesId\x18\x02 \x01(\x05:\x0b-2147483648\x12\x1d\n\x08intValue\x18\x03 \x01(\x05:\x0b-2147483648\x12\"\n\x0bstringValue\x18\x04 \x01(\t:\rENTRY_MISSING\x12\x13\n\x0b\x64oubleValue\x18\x05 \x03(\x01\x12\'\n\x08subField\x18\x06 \x03(\x0b\x32\x15.iobinary.NestedFieldB\x1d\n\x14\x64\x65.dlr.fame.protobufB\x05\x46ield'
)




_NESTEDFIELD = _descriptor.Descriptor(
  name='NestedField',
  full_name='iobinary.NestedField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fieldName', full_name='iobinary.NestedField.fieldName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seriesId', full_name='iobinary.NestedField.seriesId', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-2147483648,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intValue', full_name='iobinary.NestedField.intValue', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-2147483648,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stringValue', full_name='iobinary.NestedField.stringValue', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"ENTRY_MISSING".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doubleValue', full_name='iobinary.NestedField.doubleValue', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subField', full_name='iobinary.NestedField.subField', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=218,
)

_NESTEDFIELD.fields_by_name['subField'].message_type = _NESTEDFIELD
DESCRIPTOR.message_types_by_name['NestedField'] = _NESTEDFIELD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NestedField = _reflection.GeneratedProtocolMessageType('NestedField', (_message.Message,), {
  'DESCRIPTOR' : _NESTEDFIELD,
  '__module__' : 'Field_pb2'
  # @@protoc_insertion_point(class_scope:iobinary.NestedField)
  })
_sym_db.RegisterMessage(NestedField)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
