# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: InputFile.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fameio.protobuf_definitions import Contract_pb2 as Contract__pb2
from fameio.protobuf_definitions import Field_pb2 as Field__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='InputFile.proto',
  package='iobinary',
  syntax='proto2',
  serialized_options=b'\n\024de.dlr.fame.protobufB\005Input',
  serialized_pb=b'\n\x0fInputFile.proto\x12\x08iobinary\x1a\x0e\x43ontract.proto\x1a\x0b\x46ield.proto\"\xf3\x05\n\tInputData\x12\r\n\x05RunId\x18\x01 \x02(\x03\x12\x37\n\nSimulation\x18\x02 \x02(\x0b\x32#.iobinary.InputData.SimulationParam\x12/\n\x06Output\x18\x03 \x01(\x0b\x32\x1f.iobinary.InputData.OutputParam\x12\x35\n\nTimeSeries\x18\x04 \x03(\x0b\x32!.iobinary.InputData.TimeSeriesDao\x12+\n\x05\x41gent\x18\x05 \x03(\x0b\x32\x1c.iobinary.InputData.AgentDao\x12.\n\x08\x43ontract\x18\x06 \x03(\x0b\x32\x1c.communication.ProtoContract\x12\x31\n\x07Program\x18\x07 \x01(\x0b\x32 .iobinary.InputData.ProgramParam\x1a*\n\x0cProgramParam\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0c\n\x04Hash\x18\x02 \x01(\t\x1aJ\n\x0fSimulationParam\x12\x11\n\tStartTime\x18\x01 \x02(\x03\x12\x10\n\x08StopTime\x18\x02 \x02(\x03\x12\x12\n\nRandomSeed\x18\x03 \x02(\x03\x1aI\n\x0bOutputParam\x12\x10\n\x08Interval\x18\x01 \x02(\x05\x12\x0f\n\x07Process\x18\x02 \x02(\x05\x12\x17\n\x0f\x41\x63tiveClassName\x18\x03 \x03(\t\x1a\x91\x01\n\rTimeSeriesDao\x12\x10\n\x08seriesId\x18\x01 \x02(\x05\x12\x12\n\nseriesName\x18\x02 \x01(\t\x12\x32\n\x03row\x18\x03 \x03(\x0b\x32%.iobinary.InputData.TimeSeriesDao.Row\x1a&\n\x03Row\x12\x10\n\x08timeStep\x18\x01 \x02(\x03\x12\r\n\x05value\x18\x02 \x02(\x01\x1aO\n\x08\x41gentDao\x12\n\n\x02id\x18\x01 \x02(\x03\x12\x11\n\tclassName\x18\x02 \x02(\t\x12$\n\x05\x66ield\x18\x03 \x03(\x0b\x32\x15.iobinary.NestedFieldB\x1d\n\x14\x64\x65.dlr.fame.protobufB\x05Input'
  ,
  dependencies=[Contract__pb2.DESCRIPTOR,Field__pb2.DESCRIPTOR,])




_INPUTDATA_PROGRAMPARAM = _descriptor.Descriptor(
  name='ProgramParam',
  full_name='iobinary.InputData.ProgramParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Name', full_name='iobinary.InputData.ProgramParam.Name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Hash', full_name='iobinary.InputData.ProgramParam.Hash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=392,
  serialized_end=434,
)

_INPUTDATA_SIMULATIONPARAM = _descriptor.Descriptor(
  name='SimulationParam',
  full_name='iobinary.InputData.SimulationParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='StartTime', full_name='iobinary.InputData.SimulationParam.StartTime', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='StopTime', full_name='iobinary.InputData.SimulationParam.StopTime', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='RandomSeed', full_name='iobinary.InputData.SimulationParam.RandomSeed', index=2,
      number=3, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=436,
  serialized_end=510,
)

_INPUTDATA_OUTPUTPARAM = _descriptor.Descriptor(
  name='OutputParam',
  full_name='iobinary.InputData.OutputParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Interval', full_name='iobinary.InputData.OutputParam.Interval', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Process', full_name='iobinary.InputData.OutputParam.Process', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ActiveClassName', full_name='iobinary.InputData.OutputParam.ActiveClassName', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=512,
  serialized_end=585,
)

_INPUTDATA_TIMESERIESDAO_ROW = _descriptor.Descriptor(
  name='Row',
  full_name='iobinary.InputData.TimeSeriesDao.Row',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeStep', full_name='iobinary.InputData.TimeSeriesDao.Row.timeStep', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='iobinary.InputData.TimeSeriesDao.Row.value', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=695,
  serialized_end=733,
)

_INPUTDATA_TIMESERIESDAO = _descriptor.Descriptor(
  name='TimeSeriesDao',
  full_name='iobinary.InputData.TimeSeriesDao',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seriesId', full_name='iobinary.InputData.TimeSeriesDao.seriesId', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seriesName', full_name='iobinary.InputData.TimeSeriesDao.seriesName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row', full_name='iobinary.InputData.TimeSeriesDao.row', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INPUTDATA_TIMESERIESDAO_ROW, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=733,
)

_INPUTDATA_AGENTDAO = _descriptor.Descriptor(
  name='AgentDao',
  full_name='iobinary.InputData.AgentDao',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='iobinary.InputData.AgentDao.id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='className', full_name='iobinary.InputData.AgentDao.className', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field', full_name='iobinary.InputData.AgentDao.field', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=735,
  serialized_end=814,
)

_INPUTDATA = _descriptor.Descriptor(
  name='InputData',
  full_name='iobinary.InputData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='RunId', full_name='iobinary.InputData.RunId', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Simulation', full_name='iobinary.InputData.Simulation', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Output', full_name='iobinary.InputData.Output', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='TimeSeries', full_name='iobinary.InputData.TimeSeries', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Agent', full_name='iobinary.InputData.Agent', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Contract', full_name='iobinary.InputData.Contract', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Program', full_name='iobinary.InputData.Program', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INPUTDATA_PROGRAMPARAM, _INPUTDATA_SIMULATIONPARAM, _INPUTDATA_OUTPUTPARAM, _INPUTDATA_TIMESERIESDAO, _INPUTDATA_AGENTDAO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=814,
)

_INPUTDATA_PROGRAMPARAM.containing_type = _INPUTDATA
_INPUTDATA_SIMULATIONPARAM.containing_type = _INPUTDATA
_INPUTDATA_OUTPUTPARAM.containing_type = _INPUTDATA
_INPUTDATA_TIMESERIESDAO_ROW.containing_type = _INPUTDATA_TIMESERIESDAO
_INPUTDATA_TIMESERIESDAO.fields_by_name['row'].message_type = _INPUTDATA_TIMESERIESDAO_ROW
_INPUTDATA_TIMESERIESDAO.containing_type = _INPUTDATA
_INPUTDATA_AGENTDAO.fields_by_name['field'].message_type = Field__pb2._NESTEDFIELD
_INPUTDATA_AGENTDAO.containing_type = _INPUTDATA
_INPUTDATA.fields_by_name['Simulation'].message_type = _INPUTDATA_SIMULATIONPARAM
_INPUTDATA.fields_by_name['Output'].message_type = _INPUTDATA_OUTPUTPARAM
_INPUTDATA.fields_by_name['TimeSeries'].message_type = _INPUTDATA_TIMESERIESDAO
_INPUTDATA.fields_by_name['Agent'].message_type = _INPUTDATA_AGENTDAO
_INPUTDATA.fields_by_name['Contract'].message_type = Contract__pb2._PROTOCONTRACT
_INPUTDATA.fields_by_name['Program'].message_type = _INPUTDATA_PROGRAMPARAM
DESCRIPTOR.message_types_by_name['InputData'] = _INPUTDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InputData = _reflection.GeneratedProtocolMessageType('InputData', (_message.Message,), {

  'ProgramParam' : _reflection.GeneratedProtocolMessageType('ProgramParam', (_message.Message,), {
    'DESCRIPTOR' : _INPUTDATA_PROGRAMPARAM,
    '__module__' : 'InputFile_pb2'
    # @@protoc_insertion_point(class_scope:iobinary.InputData.ProgramParam)
    })
  ,

  'SimulationParam' : _reflection.GeneratedProtocolMessageType('SimulationParam', (_message.Message,), {
    'DESCRIPTOR' : _INPUTDATA_SIMULATIONPARAM,
    '__module__' : 'InputFile_pb2'
    # @@protoc_insertion_point(class_scope:iobinary.InputData.SimulationParam)
    })
  ,

  'OutputParam' : _reflection.GeneratedProtocolMessageType('OutputParam', (_message.Message,), {
    'DESCRIPTOR' : _INPUTDATA_OUTPUTPARAM,
    '__module__' : 'InputFile_pb2'
    # @@protoc_insertion_point(class_scope:iobinary.InputData.OutputParam)
    })
  ,

  'TimeSeriesDao' : _reflection.GeneratedProtocolMessageType('TimeSeriesDao', (_message.Message,), {

    'Row' : _reflection.GeneratedProtocolMessageType('Row', (_message.Message,), {
      'DESCRIPTOR' : _INPUTDATA_TIMESERIESDAO_ROW,
      '__module__' : 'InputFile_pb2'
      # @@protoc_insertion_point(class_scope:iobinary.InputData.TimeSeriesDao.Row)
      })
    ,
    'DESCRIPTOR' : _INPUTDATA_TIMESERIESDAO,
    '__module__' : 'InputFile_pb2'
    # @@protoc_insertion_point(class_scope:iobinary.InputData.TimeSeriesDao)
    })
  ,

  'AgentDao' : _reflection.GeneratedProtocolMessageType('AgentDao', (_message.Message,), {
    'DESCRIPTOR' : _INPUTDATA_AGENTDAO,
    '__module__' : 'InputFile_pb2'
    # @@protoc_insertion_point(class_scope:iobinary.InputData.AgentDao)
    })
  ,
  'DESCRIPTOR' : _INPUTDATA,
  '__module__' : 'InputFile_pb2'
  # @@protoc_insertion_point(class_scope:iobinary.InputData)
  })
_sym_db.RegisterMessage(InputData)
_sym_db.RegisterMessage(InputData.ProgramParam)
_sym_db.RegisterMessage(InputData.SimulationParam)
_sym_db.RegisterMessage(InputData.OutputParam)
_sym_db.RegisterMessage(InputData.TimeSeriesDao)
_sym_db.RegisterMessage(InputData.TimeSeriesDao.Row)
_sym_db.RegisterMessage(InputData.AgentDao)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
